@@ -16,6 +16,7 @@
 -- You should have received a copy of the GNU Affero General Public License
 -- along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE DeriveGeneric #-}
 
 import HOpenPGP.Tools.Common (banner, versioner, warranty, keyMatchesFingerprint, keyMatchesEightOctetKeyId, keyMatchesUIDSubString)
@@ -26,7 +27,10 @@ import Codec.Encryption.OpenPGP.KeySelection (parseEightOctetKeyId, parseFingerp
 import Codec.Encryption.OpenPGP.Serialize ()
 import Codec.Encryption.OpenPGP.Signatures (verifyTKWith, verifySigWith, verifyAgainstKeyring)
 import Codec.Encryption.OpenPGP.Types
-import Control.Applicative ((<$>),(<*>), optional, (<|>), pure)
+#if !MIN_VERSION_base(4,8,0)
+import Control.Applicative ((<$>),(<*>), pure)
+#endif
+import Control.Applicative (optional, (<|>))
 import Control.Arrow ((&&&))
 import Control.Lens ((^.), _1, _2, (^..))
 import Control.Monad.Trans.Resource (runResourceT, MonadResource)
@@ -57,12 +61,17 @@ import Data.List (nub, sort)
 import Data.Map (Map)
 import qualified Data.Map as Map
 import Data.Maybe (fromMaybe, mapMaybe, listToMaybe)
-import Data.Monoid ((<>), mconcat)
+#if !MIN_VERSION_base(4,8,0)
+import Data.Monoid (mconcat)
+#endif
+import Data.Monoid ((<>))
 import Data.Text (Text)
 import qualified Data.Text as T
 import qualified Data.Text.Lazy.IO as TLIO
 import Data.Time.Clock.POSIX (getPOSIXTime, posixSecondsToUTCTime)
+#if !MIN_VERSION_base(4,8,0)
 import Data.Traversable (traverse)
+#endif
 import Data.Tuple (swap)
 import qualified Data.Yaml as Y
 import GHC.Generics
@@ -119,7 +128,7 @@ tkToTKey tk = TKey {
                    <*> show . _pkalgo
                    <*> pkalgoAbbrev . _pkalgo
                    <*> either (const "unknown") (show . pretty) . eightOctetKeyID
-                   <*> show . fingerprint
+                   <*> show . pretty . fingerprint
 
 showTKey :: TKey -> IO ()
 showTKey key = putDoc $
