@@ -18,6 +18,8 @@
 -- You should have received a copy of the GNU Affero General Public License
 -- along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+{-# LANGUAGE CPP #-}
+
 import Paths_hopenpgp_tools (version)
 import HOpenPGP.Tools.Common (banner, versioner, warranty, prependAuto)
 import HOpenPGP.Tools.Parser (parsePExp)
@@ -25,7 +27,10 @@ import qualified Codec.Encryption.OpenPGP.ASCIIArmor as AA
 import Codec.Encryption.OpenPGP.ASCIIArmor.Types (Armor(..), ArmorType(..))
 import Codec.Encryption.OpenPGP.Serialize ()
 import Codec.Encryption.OpenPGP.Types
-import Control.Applicative ((<$>), (<*>), optional, pure)
+#if !MIN_VERSION_base(4,8,0)
+import Control.Applicative ((<$>), (<*>))
+#endif
+import Control.Applicative (optional)
 import Control.Error.Util (note)
 import Control.Monad.IO.Class (MonadIO, liftIO)
 import Control.Monad.Trans.Resource (runResourceT)
